/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 75 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"

#line 111 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 79 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 82 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 85 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 36 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 88 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 91 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 124 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 37 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlist.sip"
#include <qlist.h>
#include <qvector.h>
#line 128 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 163 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 166 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 169 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 200 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 205 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 208 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 211 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 214 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 217 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 220 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 223 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 226 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 229 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 232 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 235 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 238 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 241 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 244 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQItemModelBarDataProxy.cpp"


class sipQtDataVisualization_QItemModelBarDataProxy : public ::QtDataVisualization::QItemModelBarDataProxy
{
public:
    sipQtDataVisualization_QItemModelBarDataProxy(::QAbstractItemModel*, ::QObject*);
    sipQtDataVisualization_QItemModelBarDataProxy(::QAbstractItemModel*, const ::QString&, ::QObject*);
    sipQtDataVisualization_QItemModelBarDataProxy(::QAbstractItemModel*, const ::QString&, const ::QString&, const ::QString&, ::QObject*);
    sipQtDataVisualization_QItemModelBarDataProxy(::QAbstractItemModel*, const ::QString&, const ::QString&, const ::QString&, const ::QString&, ::QObject*);
    sipQtDataVisualization_QItemModelBarDataProxy(::QAbstractItemModel*, const ::QString&, const ::QString&, const ::QString&, const ::QStringList&, const ::QStringList&, ::QObject*);
    sipQtDataVisualization_QItemModelBarDataProxy(::QAbstractItemModel*, const ::QString&, const ::QString&, const ::QString&, const ::QString&, const ::QStringList&, const ::QStringList&, ::QObject*);
    sipQtDataVisualization_QItemModelBarDataProxy(::QObject*);
    virtual ~sipQtDataVisualization_QItemModelBarDataProxy();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtDataVisualization_QItemModelBarDataProxy(const sipQtDataVisualization_QItemModelBarDataProxy &);
    sipQtDataVisualization_QItemModelBarDataProxy &operator = (const sipQtDataVisualization_QItemModelBarDataProxy &);

    char sipPyMethods[7];
};

sipQtDataVisualization_QItemModelBarDataProxy::sipQtDataVisualization_QItemModelBarDataProxy(::QAbstractItemModel*a0, ::QObject*a1): ::QtDataVisualization::QItemModelBarDataProxy(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QItemModelBarDataProxy::sipQtDataVisualization_QItemModelBarDataProxy(::QAbstractItemModel*a0, const ::QString& a1, ::QObject*a2): ::QtDataVisualization::QItemModelBarDataProxy(a0, a1, a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QItemModelBarDataProxy::sipQtDataVisualization_QItemModelBarDataProxy(::QAbstractItemModel*a0, const ::QString& a1, const ::QString& a2, const ::QString& a3, ::QObject*a4): ::QtDataVisualization::QItemModelBarDataProxy(a0, a1, a2, a3, a4), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QItemModelBarDataProxy::sipQtDataVisualization_QItemModelBarDataProxy(::QAbstractItemModel*a0, const ::QString& a1, const ::QString& a2, const ::QString& a3, const ::QString& a4, ::QObject*a5): ::QtDataVisualization::QItemModelBarDataProxy(a0, a1, a2, a3, a4, a5), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QItemModelBarDataProxy::sipQtDataVisualization_QItemModelBarDataProxy(::QAbstractItemModel*a0, const ::QString& a1, const ::QString& a2, const ::QString& a3, const ::QStringList& a4, const ::QStringList& a5, ::QObject*a6): ::QtDataVisualization::QItemModelBarDataProxy(a0, a1, a2, a3, a4, a5, a6), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QItemModelBarDataProxy::sipQtDataVisualization_QItemModelBarDataProxy(::QAbstractItemModel*a0, const ::QString& a1, const ::QString& a2, const ::QString& a3, const ::QString& a4, const ::QStringList& a5, const ::QStringList& a6, ::QObject*a7): ::QtDataVisualization::QItemModelBarDataProxy(a0, a1, a2, a3, a4, a5, a6, a7), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QItemModelBarDataProxy::sipQtDataVisualization_QItemModelBarDataProxy(::QObject*a0): ::QtDataVisualization::QItemModelBarDataProxy(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QItemModelBarDataProxy::~sipQtDataVisualization_QItemModelBarDataProxy()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtDataVisualization_QItemModelBarDataProxy::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QtDataVisualization_QItemModelBarDataProxy);

    return ::QtDataVisualization::QItemModelBarDataProxy::metaObject();
}

int sipQtDataVisualization_QItemModelBarDataProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtDataVisualization::QItemModelBarDataProxy::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QtDataVisualization_QItemModelBarDataProxy, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtDataVisualization_QItemModelBarDataProxy::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QtDataVisualization_QItemModelBarDataProxy, _clname, &sipCpp) ? sipCpp : ::QtDataVisualization::QItemModelBarDataProxy::qt_metacast(_clname));
}

bool sipQtDataVisualization_QItemModelBarDataProxy::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtDataVisualization::QItemModelBarDataProxy::event(a0);

    extern bool sipVH_QtDataVisualization_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_15(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtDataVisualization_QItemModelBarDataProxy::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtDataVisualization::QItemModelBarDataProxy::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_16(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtDataVisualization_QItemModelBarDataProxy::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QItemModelBarDataProxy::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_17(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QItemModelBarDataProxy::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QItemModelBarDataProxy::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QItemModelBarDataProxy::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QItemModelBarDataProxy::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QItemModelBarDataProxy::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QItemModelBarDataProxy::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QItemModelBarDataProxy::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QItemModelBarDataProxy::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setItemModel, "setItemModel(self, itemModel: QAbstractItemModel|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setItemModel(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setItemModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, &a0Keep, sipType_QAbstractItemModel, &a0))
        {
            sipCpp->setItemModel(a0);

            sipKeepReference(sipSelf, 120, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setItemModel, doc_QtDataVisualization_QItemModelBarDataProxy_setItemModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_itemModel, "itemModel(self) -> QAbstractItemModel|None");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_itemModel(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_itemModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            ::QAbstractItemModel*sipRes;

            sipRes = sipCpp->itemModel();

            return sipConvertFromType(sipRes, sipType_QAbstractItemModel, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_itemModel, doc_QtDataVisualization_QItemModelBarDataProxy_itemModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setRowRole, "setRowRole(self, role: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setRowRole(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setRowRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setRowRole(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setRowRole, doc_QtDataVisualization_QItemModelBarDataProxy_setRowRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_rowRole, "rowRole(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_rowRole(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_rowRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->rowRole());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_rowRole, doc_QtDataVisualization_QItemModelBarDataProxy_rowRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setColumnRole, "setColumnRole(self, role: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setColumnRole(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setColumnRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setColumnRole(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setColumnRole, doc_QtDataVisualization_QItemModelBarDataProxy_setColumnRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_columnRole, "columnRole(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_columnRole(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_columnRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->columnRole());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_columnRole, doc_QtDataVisualization_QItemModelBarDataProxy_columnRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setValueRole, "setValueRole(self, role: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setValueRole(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setValueRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setValueRole(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setValueRole, doc_QtDataVisualization_QItemModelBarDataProxy_setValueRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_valueRole, "valueRole(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_valueRole(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_valueRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->valueRole());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_valueRole, doc_QtDataVisualization_QItemModelBarDataProxy_valueRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setRowCategories, "setRowCategories(self, categories: Iterable[str|None])");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setRowCategories(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setRowCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->setRowCategories(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setRowCategories, doc_QtDataVisualization_QItemModelBarDataProxy_setRowCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_rowCategories, "rowCategories(self) -> list[str]");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_rowCategories(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_rowCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->rowCategories());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_rowCategories, doc_QtDataVisualization_QItemModelBarDataProxy_rowCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setColumnCategories, "setColumnCategories(self, categories: Iterable[str|None])");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setColumnCategories(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setColumnCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->setColumnCategories(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setColumnCategories, doc_QtDataVisualization_QItemModelBarDataProxy_setColumnCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_columnCategories, "columnCategories(self) -> list[str]");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_columnCategories(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_columnCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->columnCategories());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_columnCategories, doc_QtDataVisualization_QItemModelBarDataProxy_columnCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setUseModelCategories, "setUseModelCategories(self, enable: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setUseModelCategories(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setUseModelCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, &a0))
        {
            sipCpp->setUseModelCategories(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setUseModelCategories, doc_QtDataVisualization_QItemModelBarDataProxy_setUseModelCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_useModelCategories, "useModelCategories(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_useModelCategories(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_useModelCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->useModelCategories();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_useModelCategories, doc_QtDataVisualization_QItemModelBarDataProxy_useModelCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setAutoRowCategories, "setAutoRowCategories(self, enable: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setAutoRowCategories(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setAutoRowCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, &a0))
        {
            sipCpp->setAutoRowCategories(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setAutoRowCategories, doc_QtDataVisualization_QItemModelBarDataProxy_setAutoRowCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_autoRowCategories, "autoRowCategories(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_autoRowCategories(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_autoRowCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->autoRowCategories();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_autoRowCategories, doc_QtDataVisualization_QItemModelBarDataProxy_autoRowCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setAutoColumnCategories, "setAutoColumnCategories(self, enable: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setAutoColumnCategories(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setAutoColumnCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, &a0))
        {
            sipCpp->setAutoColumnCategories(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setAutoColumnCategories, doc_QtDataVisualization_QItemModelBarDataProxy_setAutoColumnCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_autoColumnCategories, "autoColumnCategories(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_autoColumnCategories(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_autoColumnCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->autoColumnCategories();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_autoColumnCategories, doc_QtDataVisualization_QItemModelBarDataProxy_autoColumnCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_rowCategoryIndex, "rowCategoryIndex(self, category: str|None) -> int");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_rowCategoryIndex(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_rowCategoryIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            int sipRes;

            sipRes = sipCpp->rowCategoryIndex(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_rowCategoryIndex, doc_QtDataVisualization_QItemModelBarDataProxy_rowCategoryIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_columnCategoryIndex, "columnCategoryIndex(self, category: str|None) -> int");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_columnCategoryIndex(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_columnCategoryIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            int sipRes;

            sipRes = sipCpp->columnCategoryIndex(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_columnCategoryIndex, doc_QtDataVisualization_QItemModelBarDataProxy_columnCategoryIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setRotationRole, "setRotationRole(self, role: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setRotationRole(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setRotationRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setRotationRole(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setRotationRole, doc_QtDataVisualization_QItemModelBarDataProxy_setRotationRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_rotationRole, "rotationRole(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_rotationRole(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_rotationRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->rotationRole());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_rotationRole, doc_QtDataVisualization_QItemModelBarDataProxy_rotationRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_remap, "remap(self, rowRole: str|None, columnRole: str|None, valueRole: str|None, rotationRole: str|None, rowCategories: Iterable[str|None], columnCategories: Iterable[str|None])");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_remap(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_remap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        const ::QString* a3;
        int a3State = 0;
        const ::QStringList* a4;
        int a4State = 0;
        const ::QStringList* a5;
        int a5State = 0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1J1J1J1J1", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, sipType_QString, &a3, &a3State, sipType_QStringList, &a4, &a4State, sipType_QStringList, &a5, &a5State))
        {
            sipCpp->remap(*a0, *a1, *a2, *a3, *a4, *a5);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(const_cast< ::QString *>(a3), sipType_QString, a3State);
            sipReleaseType(const_cast< ::QStringList *>(a4), sipType_QStringList, a4State);
            sipReleaseType(const_cast< ::QStringList *>(a5), sipType_QStringList, a5State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_remap, doc_QtDataVisualization_QItemModelBarDataProxy_remap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setRowRolePattern, "setRowRolePattern(self, pattern: QRegExp)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setRowRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setRowRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRegExp* a0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QRegExp, &a0))
        {
            sipCpp->setRowRolePattern(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setRowRolePattern, doc_QtDataVisualization_QItemModelBarDataProxy_setRowRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_rowRolePattern, "rowRolePattern(self) -> QRegExp");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_rowRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_rowRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            ::QRegExp*sipRes;

            sipRes = new ::QRegExp(sipCpp->rowRolePattern());

            return sipConvertFromNewType(sipRes, sipType_QRegExp, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_rowRolePattern, doc_QtDataVisualization_QItemModelBarDataProxy_rowRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setColumnRolePattern, "setColumnRolePattern(self, pattern: QRegExp)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setColumnRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setColumnRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRegExp* a0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QRegExp, &a0))
        {
            sipCpp->setColumnRolePattern(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setColumnRolePattern, doc_QtDataVisualization_QItemModelBarDataProxy_setColumnRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_columnRolePattern, "columnRolePattern(self) -> QRegExp");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_columnRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_columnRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            ::QRegExp*sipRes;

            sipRes = new ::QRegExp(sipCpp->columnRolePattern());

            return sipConvertFromNewType(sipRes, sipType_QRegExp, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_columnRolePattern, doc_QtDataVisualization_QItemModelBarDataProxy_columnRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setValueRolePattern, "setValueRolePattern(self, pattern: QRegExp)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setValueRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setValueRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRegExp* a0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QRegExp, &a0))
        {
            sipCpp->setValueRolePattern(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setValueRolePattern, doc_QtDataVisualization_QItemModelBarDataProxy_setValueRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_valueRolePattern, "valueRolePattern(self) -> QRegExp");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_valueRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_valueRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            ::QRegExp*sipRes;

            sipRes = new ::QRegExp(sipCpp->valueRolePattern());

            return sipConvertFromNewType(sipRes, sipType_QRegExp, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_valueRolePattern, doc_QtDataVisualization_QItemModelBarDataProxy_valueRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setRotationRolePattern, "setRotationRolePattern(self, pattern: QRegExp)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setRotationRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setRotationRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRegExp* a0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QRegExp, &a0))
        {
            sipCpp->setRotationRolePattern(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setRotationRolePattern, doc_QtDataVisualization_QItemModelBarDataProxy_setRotationRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_rotationRolePattern, "rotationRolePattern(self) -> QRegExp");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_rotationRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_rotationRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            ::QRegExp*sipRes;

            sipRes = new ::QRegExp(sipCpp->rotationRolePattern());

            return sipConvertFromNewType(sipRes, sipType_QRegExp, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_rotationRolePattern, doc_QtDataVisualization_QItemModelBarDataProxy_rotationRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setRowRoleReplace, "setRowRoleReplace(self, replace: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setRowRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setRowRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setRowRoleReplace(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setRowRoleReplace, doc_QtDataVisualization_QItemModelBarDataProxy_setRowRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_rowRoleReplace, "rowRoleReplace(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_rowRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_rowRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->rowRoleReplace());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_rowRoleReplace, doc_QtDataVisualization_QItemModelBarDataProxy_rowRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setColumnRoleReplace, "setColumnRoleReplace(self, replace: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setColumnRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setColumnRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setColumnRoleReplace(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setColumnRoleReplace, doc_QtDataVisualization_QItemModelBarDataProxy_setColumnRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_columnRoleReplace, "columnRoleReplace(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_columnRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_columnRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->columnRoleReplace());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_columnRoleReplace, doc_QtDataVisualization_QItemModelBarDataProxy_columnRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setValueRoleReplace, "setValueRoleReplace(self, replace: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setValueRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setValueRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setValueRoleReplace(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setValueRoleReplace, doc_QtDataVisualization_QItemModelBarDataProxy_setValueRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_valueRoleReplace, "valueRoleReplace(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_valueRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_valueRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->valueRoleReplace());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_valueRoleReplace, doc_QtDataVisualization_QItemModelBarDataProxy_valueRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setRotationRoleReplace, "setRotationRoleReplace(self, replace: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setRotationRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setRotationRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setRotationRoleReplace(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setRotationRoleReplace, doc_QtDataVisualization_QItemModelBarDataProxy_setRotationRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_rotationRoleReplace, "rotationRoleReplace(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_rotationRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_rotationRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->rotationRoleReplace());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_rotationRoleReplace, doc_QtDataVisualization_QItemModelBarDataProxy_rotationRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_setMultiMatchBehavior, "setMultiMatchBehavior(self, behavior: QItemModelBarDataProxy.MultiMatchBehavior)");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setMultiMatchBehavior(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_setMultiMatchBehavior(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QItemModelBarDataProxy::MultiMatchBehavior a0;
        ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp, sipType_QtDataVisualization_QItemModelBarDataProxy_MultiMatchBehavior, &a0))
        {
            sipCpp->setMultiMatchBehavior(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_setMultiMatchBehavior, doc_QtDataVisualization_QItemModelBarDataProxy_setMultiMatchBehavior);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy_multiMatchBehavior, "multiMatchBehavior(self) -> QItemModelBarDataProxy.MultiMatchBehavior");

extern "C" {static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_multiMatchBehavior(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QItemModelBarDataProxy_multiMatchBehavior(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QItemModelBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QItemModelBarDataProxy, &sipCpp))
        {
            ::QtDataVisualization::QItemModelBarDataProxy::MultiMatchBehavior sipRes;

            sipRes = sipCpp->multiMatchBehavior();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtDataVisualization_QItemModelBarDataProxy_MultiMatchBehavior);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelBarDataProxy, sipName_multiMatchBehavior, doc_QtDataVisualization_QItemModelBarDataProxy_multiMatchBehavior);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtDataVisualization_QItemModelBarDataProxy(void *, const sipTypeDef *);}
static void *cast_QtDataVisualization_QItemModelBarDataProxy(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtDataVisualization::QItemModelBarDataProxy *sipCpp = reinterpret_cast< ::QtDataVisualization::QItemModelBarDataProxy *>(sipCppV);

    if (targetType == sipType_QtDataVisualization_QItemModelBarDataProxy)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QtDataVisualization_QBarDataProxy)->ctd_cast(static_cast< ::QtDataVisualization::QBarDataProxy *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_QItemModelBarDataProxy(void *, int);}
static void release_QtDataVisualization_QItemModelBarDataProxy(void *sipCppV, int)
{
    ::QtDataVisualization::QItemModelBarDataProxy *sipCpp = reinterpret_cast< ::QtDataVisualization::QItemModelBarDataProxy *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtDataVisualization_QItemModelBarDataProxy(Py_ssize_t);}
static void *array_QtDataVisualization_QItemModelBarDataProxy(Py_ssize_t sipNrElem)
{
    return new ::QtDataVisualization::QItemModelBarDataProxy[sipNrElem];
}


extern "C" {static void array_delete_QtDataVisualization_QItemModelBarDataProxy(void *);}
static void array_delete_QtDataVisualization_QItemModelBarDataProxy(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtDataVisualization::QItemModelBarDataProxy *>(sipCpp);
}


extern "C" {static void dealloc_QtDataVisualization_QItemModelBarDataProxy(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_QItemModelBarDataProxy(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtDataVisualization_QItemModelBarDataProxy *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_QItemModelBarDataProxy(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtDataVisualization_QItemModelBarDataProxy(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtDataVisualization_QItemModelBarDataProxy(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtDataVisualization_QItemModelBarDataProxy *sipCpp = SIP_NULLPTR;

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8|JH", &a0Keep, sipType_QAbstractItemModel, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QItemModelBarDataProxy(a0, a1);

            sipKeepReference((PyObject *)sipSelf, 120, a0Keep);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        const ::QString* a1;
        int a1State = 0;
        ::QObject* a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8J1|JH", &a0Keep, sipType_QAbstractItemModel, &a0, sipType_QString, &a1, &a1State, sipType_QObject, &a2, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QItemModelBarDataProxy(a0, *a1, a2);

            sipKeepReference((PyObject *)sipSelf, 120, a0Keep);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        const ::QString* a3;
        int a3State = 0;
        ::QObject* a4 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8J1J1J1|JH", &a0Keep, sipType_QAbstractItemModel, &a0, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, sipType_QString, &a3, &a3State, sipType_QObject, &a4, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QItemModelBarDataProxy(a0, *a1, *a2, *a3, a4);

            sipKeepReference((PyObject *)sipSelf, 120, a0Keep);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(const_cast< ::QString *>(a3), sipType_QString, a3State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        const ::QString* a3;
        int a3State = 0;
        const ::QString* a4;
        int a4State = 0;
        ::QObject* a5 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8J1J1J1J1|JH", &a0Keep, sipType_QAbstractItemModel, &a0, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, sipType_QString, &a3, &a3State, sipType_QString, &a4, &a4State, sipType_QObject, &a5, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QItemModelBarDataProxy(a0, *a1, *a2, *a3, *a4, a5);

            sipKeepReference((PyObject *)sipSelf, 120, a0Keep);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(const_cast< ::QString *>(a3), sipType_QString, a3State);
            sipReleaseType(const_cast< ::QString *>(a4), sipType_QString, a4State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        const ::QString* a3;
        int a3State = 0;
        const ::QStringList* a4;
        int a4State = 0;
        const ::QStringList* a5;
        int a5State = 0;
        ::QObject* a6 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8J1J1J1J1J1|JH", &a0Keep, sipType_QAbstractItemModel, &a0, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, sipType_QString, &a3, &a3State, sipType_QStringList, &a4, &a4State, sipType_QStringList, &a5, &a5State, sipType_QObject, &a6, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QItemModelBarDataProxy(a0, *a1, *a2, *a3, *a4, *a5, a6);

            sipKeepReference((PyObject *)sipSelf, 120, a0Keep);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(const_cast< ::QString *>(a3), sipType_QString, a3State);
            sipReleaseType(const_cast< ::QStringList *>(a4), sipType_QStringList, a4State);
            sipReleaseType(const_cast< ::QStringList *>(a5), sipType_QStringList, a5State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        const ::QString* a3;
        int a3State = 0;
        const ::QString* a4;
        int a4State = 0;
        const ::QStringList* a5;
        int a5State = 0;
        const ::QStringList* a6;
        int a6State = 0;
        ::QObject* a7 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8J1J1J1J1J1J1|JH", &a0Keep, sipType_QAbstractItemModel, &a0, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, sipType_QString, &a3, &a3State, sipType_QString, &a4, &a4State, sipType_QStringList, &a5, &a5State, sipType_QStringList, &a6, &a6State, sipType_QObject, &a7, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QItemModelBarDataProxy(a0, *a1, *a2, *a3, *a4, *a5, *a6, a7);

            sipKeepReference((PyObject *)sipSelf, 120, a0Keep);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(const_cast< ::QString *>(a3), sipType_QString, a3State);
            sipReleaseType(const_cast< ::QString *>(a4), sipType_QString, a4State);
            sipReleaseType(const_cast< ::QStringList *>(a5), sipType_QStringList, a5State);
            sipReleaseType(const_cast< ::QStringList *>(a6), sipType_QStringList, a6State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QItemModelBarDataProxy(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtDataVisualization_QItemModelBarDataProxy[] = {{48, 255, 1}};


static PyMethodDef methods_QtDataVisualization_QItemModelBarDataProxy[] = {
    {sipName_autoColumnCategories, meth_QtDataVisualization_QItemModelBarDataProxy_autoColumnCategories, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_autoColumnCategories},
    {sipName_autoRowCategories, meth_QtDataVisualization_QItemModelBarDataProxy_autoRowCategories, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_autoRowCategories},
    {sipName_columnCategories, meth_QtDataVisualization_QItemModelBarDataProxy_columnCategories, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_columnCategories},
    {sipName_columnCategoryIndex, meth_QtDataVisualization_QItemModelBarDataProxy_columnCategoryIndex, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_columnCategoryIndex},
    {sipName_columnRole, meth_QtDataVisualization_QItemModelBarDataProxy_columnRole, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_columnRole},
    {sipName_columnRolePattern, meth_QtDataVisualization_QItemModelBarDataProxy_columnRolePattern, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_columnRolePattern},
    {sipName_columnRoleReplace, meth_QtDataVisualization_QItemModelBarDataProxy_columnRoleReplace, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_columnRoleReplace},
    {sipName_itemModel, meth_QtDataVisualization_QItemModelBarDataProxy_itemModel, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_itemModel},
    {sipName_multiMatchBehavior, meth_QtDataVisualization_QItemModelBarDataProxy_multiMatchBehavior, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_multiMatchBehavior},
    {sipName_remap, meth_QtDataVisualization_QItemModelBarDataProxy_remap, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_remap},
    {sipName_rotationRole, meth_QtDataVisualization_QItemModelBarDataProxy_rotationRole, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_rotationRole},
    {sipName_rotationRolePattern, meth_QtDataVisualization_QItemModelBarDataProxy_rotationRolePattern, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_rotationRolePattern},
    {sipName_rotationRoleReplace, meth_QtDataVisualization_QItemModelBarDataProxy_rotationRoleReplace, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_rotationRoleReplace},
    {sipName_rowCategories, meth_QtDataVisualization_QItemModelBarDataProxy_rowCategories, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_rowCategories},
    {sipName_rowCategoryIndex, meth_QtDataVisualization_QItemModelBarDataProxy_rowCategoryIndex, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_rowCategoryIndex},
    {sipName_rowRole, meth_QtDataVisualization_QItemModelBarDataProxy_rowRole, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_rowRole},
    {sipName_rowRolePattern, meth_QtDataVisualization_QItemModelBarDataProxy_rowRolePattern, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_rowRolePattern},
    {sipName_rowRoleReplace, meth_QtDataVisualization_QItemModelBarDataProxy_rowRoleReplace, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_rowRoleReplace},
    {sipName_setAutoColumnCategories, meth_QtDataVisualization_QItemModelBarDataProxy_setAutoColumnCategories, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setAutoColumnCategories},
    {sipName_setAutoRowCategories, meth_QtDataVisualization_QItemModelBarDataProxy_setAutoRowCategories, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setAutoRowCategories},
    {sipName_setColumnCategories, meth_QtDataVisualization_QItemModelBarDataProxy_setColumnCategories, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setColumnCategories},
    {sipName_setColumnRole, meth_QtDataVisualization_QItemModelBarDataProxy_setColumnRole, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setColumnRole},
    {sipName_setColumnRolePattern, meth_QtDataVisualization_QItemModelBarDataProxy_setColumnRolePattern, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setColumnRolePattern},
    {sipName_setColumnRoleReplace, meth_QtDataVisualization_QItemModelBarDataProxy_setColumnRoleReplace, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setColumnRoleReplace},
    {sipName_setItemModel, meth_QtDataVisualization_QItemModelBarDataProxy_setItemModel, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setItemModel},
    {sipName_setMultiMatchBehavior, meth_QtDataVisualization_QItemModelBarDataProxy_setMultiMatchBehavior, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setMultiMatchBehavior},
    {sipName_setRotationRole, meth_QtDataVisualization_QItemModelBarDataProxy_setRotationRole, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setRotationRole},
    {sipName_setRotationRolePattern, meth_QtDataVisualization_QItemModelBarDataProxy_setRotationRolePattern, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setRotationRolePattern},
    {sipName_setRotationRoleReplace, meth_QtDataVisualization_QItemModelBarDataProxy_setRotationRoleReplace, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setRotationRoleReplace},
    {sipName_setRowCategories, meth_QtDataVisualization_QItemModelBarDataProxy_setRowCategories, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setRowCategories},
    {sipName_setRowRole, meth_QtDataVisualization_QItemModelBarDataProxy_setRowRole, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setRowRole},
    {sipName_setRowRolePattern, meth_QtDataVisualization_QItemModelBarDataProxy_setRowRolePattern, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setRowRolePattern},
    {sipName_setRowRoleReplace, meth_QtDataVisualization_QItemModelBarDataProxy_setRowRoleReplace, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setRowRoleReplace},
    {sipName_setUseModelCategories, meth_QtDataVisualization_QItemModelBarDataProxy_setUseModelCategories, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setUseModelCategories},
    {sipName_setValueRole, meth_QtDataVisualization_QItemModelBarDataProxy_setValueRole, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setValueRole},
    {sipName_setValueRolePattern, meth_QtDataVisualization_QItemModelBarDataProxy_setValueRolePattern, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setValueRolePattern},
    {sipName_setValueRoleReplace, meth_QtDataVisualization_QItemModelBarDataProxy_setValueRoleReplace, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_setValueRoleReplace},
    {sipName_useModelCategories, meth_QtDataVisualization_QItemModelBarDataProxy_useModelCategories, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_useModelCategories},
    {sipName_valueRole, meth_QtDataVisualization_QItemModelBarDataProxy_valueRole, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_valueRole},
    {sipName_valueRolePattern, meth_QtDataVisualization_QItemModelBarDataProxy_valueRolePattern, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_valueRolePattern},
    {sipName_valueRoleReplace, meth_QtDataVisualization_QItemModelBarDataProxy_valueRoleReplace, METH_VARARGS, doc_QtDataVisualization_QItemModelBarDataProxy_valueRoleReplace}
};

static sipEnumMemberDef enummembers_QtDataVisualization_QItemModelBarDataProxy[] = {
    {sipName_MMBAverage, static_cast<int>(::QtDataVisualization::QItemModelBarDataProxy::MMBAverage), 55},
    {sipName_MMBCumulative, static_cast<int>(::QtDataVisualization::QItemModelBarDataProxy::MMBCumulative), 55},
    {sipName_MMBFirst, static_cast<int>(::QtDataVisualization::QItemModelBarDataProxy::MMBFirst), 55},
    {sipName_MMBLast, static_cast<int>(::QtDataVisualization::QItemModelBarDataProxy::MMBLast), 55},
};

PyDoc_STRVAR(doc_QtDataVisualization_QItemModelBarDataProxy, "\1QItemModelBarDataProxy(itemModel: QAbstractItemModel|None, parent: QObject|None = None)\n"
"QItemModelBarDataProxy(itemModel: QAbstractItemModel|None, valueRole: str|None, parent: QObject|None = None)\n"
"QItemModelBarDataProxy(itemModel: QAbstractItemModel|None, rowRole: str|None, columnRole: str|None, valueRole: str|None, parent: QObject|None = None)\n"
"QItemModelBarDataProxy(itemModel: QAbstractItemModel|None, rowRole: str|None, columnRole: str|None, valueRole: str|None, rotationRole: str|None, parent: QObject|None = None)\n"
"QItemModelBarDataProxy(itemModel: QAbstractItemModel|None, rowRole: str|None, columnRole: str|None, valueRole: str|None, rowCategories: Iterable[str|None], columnCategories: Iterable[str|None], parent: QObject|None = None)\n"
"QItemModelBarDataProxy(itemModel: QAbstractItemModel|None, rowRole: str|None, columnRole: str|None, valueRole: str|None, rotationRole: str|None, rowCategories: Iterable[str|None], columnCategories: Iterable[str|None], parent: QObject|None = None)\n"
"QItemModelBarDataProxy(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtDataVisualization_QItemModelBarDataProxy[] = {
    {"multiMatchBehaviorChanged(MultiMatchBehavior)|(QtDataVisualization::QItemModelBarDataProxy::MultiMatchBehavior)", "\1multiMatchBehaviorChanged(self, behavior: QItemModelBarDataProxy.MultiMatchBehavior)", SIP_NULLPTR, SIP_NULLPTR},
    {"rotationRoleReplaceChanged(QString)", "\1rotationRoleReplaceChanged(self, replace: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"valueRoleReplaceChanged(QString)", "\1valueRoleReplaceChanged(self, replace: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"columnRoleReplaceChanged(QString)", "\1columnRoleReplaceChanged(self, replace: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowRoleReplaceChanged(QString)", "\1rowRoleReplaceChanged(self, replace: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"rotationRolePatternChanged(QRegExp)", "\1rotationRolePatternChanged(self, pattern: QRegExp)", SIP_NULLPTR, SIP_NULLPTR},
    {"valueRolePatternChanged(QRegExp)", "\1valueRolePatternChanged(self, pattern: QRegExp)", SIP_NULLPTR, SIP_NULLPTR},
    {"columnRolePatternChanged(QRegExp)", "\1columnRolePatternChanged(self, pattern: QRegExp)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowRolePatternChanged(QRegExp)", "\1rowRolePatternChanged(self, pattern: QRegExp)", SIP_NULLPTR, SIP_NULLPTR},
    {"autoColumnCategoriesChanged(bool)", "\1autoColumnCategoriesChanged(self, enable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"autoRowCategoriesChanged(bool)", "\1autoRowCategoriesChanged(self, enable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"useModelCategoriesChanged(bool)", "\1useModelCategoriesChanged(self, enable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"columnCategoriesChanged()", "\1columnCategoriesChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowCategoriesChanged()", "\1rowCategoriesChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"rotationRoleChanged(QString)", "\1rotationRoleChanged(self, role: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"valueRoleChanged(QString)", "\1valueRoleChanged(self, role: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"columnRoleChanged(QString)", "\1columnRoleChanged(self, role: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowRoleChanged(QString)", "\1rowRoleChanged(self, role: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"itemModelChanged(const QAbstractItemModel*)", "\1itemModelChanged(self, itemModel: QAbstractItemModel|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtDataVisualization_QItemModelBarDataProxy = {
    &::QtDataVisualization::QItemModelBarDataProxy::staticMetaObject,
    0,
    signals_QtDataVisualization_QItemModelBarDataProxy,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QItemModelBarDataProxy = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__QItemModelBarDataProxy,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_QItemModelBarDataProxy,
    },
    {
        sipNameNr_QItemModelBarDataProxy,
        {0, 0, 1},
        41, methods_QtDataVisualization_QItemModelBarDataProxy,
        4, enummembers_QtDataVisualization_QItemModelBarDataProxy,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtDataVisualization_QItemModelBarDataProxy,
    -1,
    -1,
    supers_QtDataVisualization_QItemModelBarDataProxy,
    SIP_NULLPTR,
    init_type_QtDataVisualization_QItemModelBarDataProxy,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_QItemModelBarDataProxy,
    SIP_NULLPTR,
    array_QtDataVisualization_QItemModelBarDataProxy,
    SIP_NULLPTR,
    release_QtDataVisualization_QItemModelBarDataProxy,
    cast_QtDataVisualization_QItemModelBarDataProxy,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtDataVisualization_QItemModelBarDataProxy,
    sizeof (::QtDataVisualization::QItemModelBarDataProxy),
};
